Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(358)

Unified Diff: content/gpu/gpu_child_thread.h

Issue 6793054: Moved code that runs in both the browser and GPU process from content/gpu to content/common/gpu. (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 9 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/gpu/gpu_channel.cc ('k') | content/gpu/gpu_child_thread.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/gpu/gpu_child_thread.h
===================================================================
--- content/gpu/gpu_child_thread.h (revision 80399)
+++ content/gpu/gpu_child_thread.h (working copy)
@@ -15,11 +15,11 @@
#include "base/time.h"
#include "build/build_config.h"
#include "content/common/child_thread.h"
-#include "content/common/gpu_info.h"
-#include "content/gpu/gpu_channel.h"
-#include "content/gpu/gpu_config.h"
-#include "content/gpu/gpu_render_thread.h"
-#include "content/gpu/x_util.h"
+#include "content/common/gpu/gpu_channel.h"
+#include "content/common/gpu/gpu_channel_manager.h"
+#include "content/common/gpu/gpu_config.h"
+#include "content/common/gpu/gpu_info.h"
+#include "content/common/gpu/x_util.h"
#include "ui/gfx/native_widget_types.h"
namespace IPC {
@@ -34,7 +34,7 @@
// The main thread of the GPU child process. There will only ever be one of
// these per process. It does process initialization and shutdown. It forwards
// IPC messages to GpuRenderThread, which is responsible for issuing rendering
// commands to the GPU.
class GpuChildThread : public ChildThread {
public:
@@ -79,7 +79,7 @@
bool collecting_dx_diagnostics_;
#endif
- scoped_ptr<GpuRenderThread> render_thread_;
+ scoped_ptr<GpuChannelManager> gpu_channel_manager_;
// Information about the GPU, such as device and vendor ID.
GPUInfo gpu_info_;
« no previous file with comments | « content/gpu/gpu_channel.cc ('k') | content/gpu/gpu_child_thread.cc » ('j') | no next file with comments »
@@ -34,7 +34,7 @@
// The main thread of the GPU child process. There will only ever be one of
// these per process. It does process initialization and shutdown. It forwards
-// IPC messages to GpuRenderThread, which is responsible for issuing rendering
+// IPC messages to GpuChannelManager, which is responsible for issuing rendering
// commands to the GPU.
class GpuChildThread : public ChildThread {

Powered by Google App Engine
This is Rietveld 408576698